@@ -145,8 +145,8 @@ mod test {
             .unwrap();
     }
 
-    //#[test]
-    fn _test_tunneled_secure_channel_works() {
+    #[test]
+    fn test_tunneled_secure_channel_works() {
         let (mut ctx, mut executor) = ockam_node::start_node();
         executor
             .execute(async move {
@@ -198,8 +198,8 @@ mod test {
             .unwrap();
     }
 
-    //#[test]
-    fn _test_double_tunneled_secure_channel_works() {
+    #[test]
+    fn test_double_tunneled_secure_channel_works() {
         let (mut ctx, mut executor) = ockam_node::start_node();
         executor
             .execute(async move {
@@ -264,8 +264,8 @@ mod test {
             .unwrap();
     }
 
-    //#[test]
-    fn _test_many_times_tunneled_secure_channel_works() {
+    #[test]
+    fn test_many_times_tunneled_secure_channel_works() {
         let (mut ctx, mut executor) = ockam_node::start_node();
         executor
             .execute(async move {
