@@ -27,6 +27,7 @@ pub use entity_builder::*;
 pub use error::*;
 pub use identifiers::*;
 pub use key_attributes::*;
+pub use lease::*;
 use ockam_channel::SecureChannelVault;
 use ockam_core::{compat::collections::HashMap, Address, Message, Result};
 use ockam_node::{block_future, Context};
@@ -110,6 +111,7 @@ mod entity_builder;
 mod error;
 mod identifiers;
 mod key_attributes;
+mod lease;
 mod profile;
 mod profile_state;
 mod proof;
